@@ -7,7 +7,7 @@ Rule::Engine - A Rule Engine
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 DESCRIPTION
 
@@ -30,8 +30,8 @@ them against a list of objects.
         filter => Rule::Engine::Filter->new(
             condition => sub {
                 # Check something here.  Any object that returns true will
-                # be kept.
-                shift->happy ? 1 : 0
+                # be kept. Args are $self and the object
+                $_[1]->happy ? 1 : 0
             }
         )
     );
@@ -42,11 +42,11 @@ them against a list of objects.
     my $rule = Rule::Engine::Rule->new(
         name => 'temperature',
         condition => sub {
-            my ($env, $obj) = @_;
+            my ($self, $env, $obj) = @_;
             return $obj->favorite_temp == $env->get_environment('temperature');
         },
         action => sub {
-            my ($env, $obj) = @_;
+            my ($self, $env, $obj) = @_;
             $obj->happy(1);
         }
     );
@@ -71,12 +71,12 @@ to true for a given object, then the action is executed.
 	my $rule = Rule::Engine::Rule->new(
 	    name => 'check_score',
 	    condition => sub {
-	        my ($env, $obj) = @_;
+	        my ($self, $env, $obj) = @_;
 			# Test the score
 	        return $obj->score >= 59;
 	    },
 	    action => sub {
-	        my ($env, $obj) = @_;
+	        my ($self, $env, $obj) = @_;
 			# Passing score!
         	$obj->pass(1);
 	    }
@@ -98,7 +98,7 @@ after all the rules have been evaluated.
 	        condition => sub {
 	            # Check something here.  Any object that returns true will
 	            # be kept.
-	            shift->is_something ? 1 : 0
+	            $_[1]->is_something ? 1 : 0
 	        }
 	    )
 	);
